==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/sl_SI.php <==
<?php
$lang['friendlyname'] = 'Upravitelj datotek';
$lang['permission'] = 'Uporaba modula Upravitelj datotek';
$lang['permissionadvanced'] = 'Napredna uporaba modula Upravitelj datotek';
$lang['moddescription'] = 'Upravljanje z datotekami in mapami v sistemu CMS';
$lang['installed'] = 'Upravitelj datotek, različica %s, uspe&scaron;no name&scaron;čen';
$lang['postinstall'] = 'Upravitelj datotek je bil name&scaron;čen';
$lang['uninstalled'] = 'Upravitelj datotek je bil odstranjen';
$lang['really_uninstall'] = 'Ste prepričani, da želite odstraniti modul Upravitelj datotek?';
$lang['upgraded'] = 'Modul Upravitelj datotek je bil nadgrajen na različico %s';
$lang['fileview'] = 'Prikaz datotek';
$lang['switchtofileview'] = 'Preklopi na prikaz datotek';
$lang['settings'] = 'Nastavitve';
$lang['savesettings'] = 'Shrani nastavitve';
$lang['filename'] = 'Ime datoteke';
$lang['fileinfo'] = 'Informacije';
$lang['fileowner'] = 'Lastnik';
$lang['fileperms'] = 'Pravice';
$lang['filesize'] = 'Velikost';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Akcije';
$lang['delete'] = 'Izbri&scaron;i';
$lang['notwritable'] = 'Ni zapisljivo';
$lang['filetoobig'] = 'presega največjo dovoljeno velikost. Nalaganje preklicano.';
$lang['unknown'] = 'Neznano';
$lang['fileoutsideuploads'] = 'Nimate pravice za urejanje datotek izven mape za nalaganje! (To zahteva pravice za napredno upravljanje z datotekami)';
$lang['writable'] = 'Zapisljivo';
$lang['writeprotected'] = 'Za&scaron;čiteno pred pisanjem';
$lang['bytes'] = 'bajtov';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'datotek';
$lang['bytesin'] = 'bajtov v';
$lang['in'] = 'v';
$lang['file'] = 'datoteka';
$lang['fileno'] = '&Scaron;t.datoteke';
$lang['subdirs'] = 'podmape';
$lang['subdir'] = 'podmapa';
$lang['and'] = 'in';
$lang['confirmsingledelete'] = 'Ste prepričani?';
$lang['confirmsingledirdelete'] = 'Ste prepričani, da želite izbrisati to mapo?';
$lang['dirtreedeletesuccess'] = 'Mapa in njena vsebina je bila izbrisana.';
$lang['dirtreedeletefail'] = 'Napaka pri brisanju mape. Nekatere vsebine so bile morda vseeno izbrisane.';
$lang['singlefiledeletesuccess'] = 'Datoteka je bila uspe&scaron;no izbrisana';
$lang['filedeletesuccess'] = 'je uspe&scaron;no izbrisana';
$lang['singlefiledeletefail'] = 'Napaka pri poizkusu izbrisa datoteke';
$lang['filedeletefail'] = ' ni bilo mogoče izbrisati zaradi napake.';
$lang['singledirdeletesuccess'] = 'Mapa je bila uspe&scaron;no izbrisana';
$lang['singledirdeletefail'] = 'Napaka pri brisanju mape (preverite, če je prazna)';
$lang['deleteselected'] = 'Izbri&scaron;i izbrane datoteke';
$lang['confirmselected'] = 'Ste prepričani?';
$lang['confirmdeleteselected'] = 'Ste prepričani, da želite izbrisati izbrane datoteke?';
$lang['deleteselectedcancelled'] = 'Brisanje izbranih datotek preklicano';
$lang['recursetext'] = 'Poglobitev v podmape';
$lang['nofilesselected'] = 'Nobena datoteka ni izbrana';
$lang['moveselected'] = 'Premakni izbrane datoteke';
$lang['copyselected'] = 'Kopiraj izbrane datoteke';
$lang['selecttargetdir'] = 'Izberite mapo v katero želite kopirati/premakniti';
$lang['movedto'] = 'premaknjeno v';
$lang['copiedto'] = 'kopirano v';
$lang['couldnotmove'] = 'ni bilo mogoče premakniti';
$lang['couldnotcopy'] = 'ni bilo mogoče prekopirati';
$lang['rename'] = 'Preimenuj';
$lang['newname'] = 'Novo ime:';
$lang['renamesuccess'] = 'Datoteka uspe&scaron;no preimanovana';
$lang['renamefailure'] = 'Napaka pri preimenovanju datoteke';
$lang['renamecancelled'] = 'Preimenovanje preklicano';
$lang['owner'] = 'Lastnik';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostali';
$lang['newpermissions'] = 'Nove pravice:';
$lang['setpermissions'] = 'Nastavi pravice';
$lang['permissionstyle'] = 'Stil pravic';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Hiter chmod (npr. 777)';
$lang['chmod'] = 'Spremeni pravice';
$lang['chmodselected'] = 'Spremeni pravice na izbranih datotekah';
$lang['chmodsuccess'] = 'Datoteka je uspe&scaron;no dobila nove pravice';
$lang['chmodfailure'] = 'Spreminjanje pravic datoteke ni bilo uspe&scaron;no';
$lang['chmodcancelled'] = 'Spreminjanje pravic preklicano';
$lang['dirchmodfailmulti'] = 'Pri&scaron;lo je do napake pri spreminjanju pravic mape. Nekatere datoteke v tej mapi so morda kljub temu dobile nove pravice..';
$lang['dirchmodsuccessmulti'] = 'Spreminjanje pravic na mapi in njeni vsebini je bilo uspe&scaron;no';
$lang['dirchmodsuccess'] = 'Mapa je uspe&scaron;no dobila nove pravice';
$lang['dirchmodfailure'] = 'Spreminjanje pravic mape ni bilo uspe&scaron;no';
$lang['dirnotemptyconfirm'] = 'Mapa ni prazna. Ste prepričani, da jo želite izbrisati skupaj z vso vsebino in podmapami?';
$lang['dirtreedeletecancelled'] = 'Brisanje mape preklicano';
$lang['imsure'] = 'Prepričan sem';
$lang['cancel'] = 'Prekliči';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Naloži novo datoteko(e)';
$lang['unpackafterupload'] = 'Naj poizkusim ekstrahirati datoteko po naložitvi (samo tgz in zip datoteke)?';
$lang['uploadsuccess'] = 'je uspe&scaron;no naložena';
$lang['uploadfail'] = 'ni bilo mogoče naložiti';
$lang['unpacksuccess'] = 'je uspe&scaron;no ekstrahirana';
$lang['unpackfail'] = ' neuspe&scaron;no z napako:';
$lang['packfileopenfail'] = 'Ne morem odpreti kompresirane datoteke za ekstrahiranje (nepodprt format?)';
$lang['packfilewritefail'] = 'Ne morem odpreti datoteke &amp;s za pisanje';
$lang['currentpath'] = 'Trenutna pot:';
$lang['newdirname'] = 'Ustvari novo mapo:';
$lang['newdirsuccess'] = 'Mapa je bila uspe&scaron;no ustvarjena';
$lang['newdirfail'] = 'Napaka pri ustvarjanju nove mape';
$lang['filedateformat'] = 'd.m.Y H:m:s';
$lang['iconsize'] = 'Velikost ikone';
$lang['smallicons'] = 'Majhne ikone';
$lang['largeicons'] = 'Velike ikone';
$lang['thousanddelimiter'] = 'Ločitelj tisočic';
$lang['none'] = 'Noben';
$lang['showthumbnails'] = 'Prikaži pomanj&scaron;ave';
$lang['showthumbnailshelp'] = 'Če omogočite to možnost bodo prikazane pomanj&scaron;ave slikovnih datotek, če le-te obstajajo, datoteke pomanj&scaron;av bodo skrite. Če to možnost onemogočite, bodo prikazane vse datoteke.';
$lang['uploadfilesto'] = 'Nalaganje datotek v:';
$lang['uploadview'] = 'Naloži datoteke';
$lang['uploadboxes'] = '&Scaron;tevilo polj za nalaganje';
$lang['nothinguploaded'] = 'Nič ni bilo prene&scaron;eno';
$lang['unsupportedarchive'] = 'Nepodprt format arhiva';
$lang['uploadmethod'] = 'Metoda nalaganja';
$lang['uploaderstandard'] = 'Standardna HTML input metoda (omogoča ekstrahiranje)';
$lang['enableadvanced'] = 'Omogoči napredni način?';
$lang['advancedhelp'] = 'Omogoča dostop do celotnega CMS sistema, ne samo mape /uploads/ (če je to dovoljeno)';
$lang['showhiddenfileshelp'] = 'Učinkovito samo ob aktiviranem naprednem načinu';
$lang['showhiddenfiles'] = 'Prikaži skrite datoteke';
$lang['settingsconfirmsingledelete'] = 'Potrditev brisanja posamezne datoteke?';
$lang['settingssaved'] = 'Nastavitve shranjene';
$lang['help'] = '		<h3>Kaj to počne?</h3>
		<p>Modul omogoča upravljanje z datotekami</p>
		<h3>Kako to uporabim?</h3>
		<p>Izberite iz menija vsebina v administraciji. </p>';
$lang['utma'] = '156861353.587959277.1217433595.1218876433.1218884702.10';
$lang['utmz'] = '156861353.1218827009.7.4.utmccn=(organic)|utmcsr=google|utmctr=cms made simple email obfuscate|utmcmd=organic';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/sl_SI.php <==
<?php
$lang['friendlyname'] = 'Upravitelj datotek';
$lang['permission'] = 'Uporaba modula Upravitelj datotek';
$lang['permissionadvanced'] = 'Napredna uporaba modula Upravitelj datotek';
$lang['moddescription'] = 'Upravljanje z datotekami in mapami v sistemu CMS';
$lang['installed'] = 'Upravitelj datotek, različica %s, uspe&scaron;no name&scaron;čen';
$lang['postinstall'] = 'Upravitelj datotek je bil name&scaron;čen';
$lang['uninstalled'] = 'Upravitelj datotek je bil odstranjen';
$lang['really_uninstall'] = 'Ste prepričani, da želite odstraniti modul Upravitelj datotek?';
$lang['upgraded'] = 'Modul Upravitelj datotek je bil nadgrajen na različico %s';
$lang['fileview'] = 'Prikaz datotek';
$lang['switchtofileview'] = 'Preklopi na prikaz datotek';
$lang['settings'] = 'Nastavitve';
$lang['savesettings'] = 'Shrani nastavitve';
$lang['filename'] = 'Ime datoteke';
$lang['fileinfo'] = 'Informacije';
$lang['fileowner'] = 'Lastnik';
$lang['fileperms'] = 'Pravice';
$lang['filesize'] = 'Velikost';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Akcije';
$lang['delete'] = 'Izbri&scaron;i';
$lang['notwritable'] = 'Ni zapisljivo';
$lang['filetoobig'] = 'presega največjo dovoljeno velikost. Nalaganje preklicano.';
$lang['unknown'] = 'Neznano';
$lang['fileoutsideuploads'] = 'Nimate pravice za urejanje datotek izven mape za nalaganje! (To zahteva pravice za napredno upravljanje z datotekami)';
$lang['writable'] = 'Zapisljivo';
$lang['writeprotected'] = 'Za&scaron;čiteno pred pisanjem';
$lang['bytes'] = 'bajtov';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'datotek';
$lang['bytesin'] = 'bajtov v';
$lang['in'] = 'v';
$lang['file'] = 'datoteka';
$lang['fileno'] = '&Scaron;t.datoteke';
$lang['subdirs'] = 'podmape';
$lang['subdir'] = 'podmapa';
$lang['and'] = 'in';
$lang['confirmsingledelete'] = 'Ste prepričani?';
$lang['confirmsingledirdelete'] = 'Ste prepričani, da želite izbrisati to mapo?';
$lang['dirtreedeletesuccess'] = 'Mapa in njena vsebina je bila izbrisana.';
$lang['dirtreedeletefail'] = 'Napaka pri brisanju mape. Nekatere vsebine so bile morda vseeno izbrisane.';
$lang['singlefiledeletesuccess'] = 'Datoteka je bila uspe&scaron;no izbrisana';
$lang['filedeletesuccess'] = 'je uspe&scaron;no izbrisana';
$lang['singlefiledeletefail'] = 'Napaka pri poizkusu izbrisa datoteke';
$lang['filedeletefail'] = ' ni bilo mogoče izbrisati zaradi napake.';
$lang['singledirdeletesuccess'] = 'Mapa je bila uspe&scaron;no izbrisana';
$lang['singledirdeletefail'] = 'Napaka pri brisanju mape (preverite, če je prazna)';
$lang['deleteselected'] = 'Izbri&scaron;i izbrane datoteke';
$lang['confirmselected'] = 'Ste prepričani?';
$lang['confirmdeleteselected'] = 'Ste prepričani, da želite izbrisati izbrane datoteke?';
$lang['deleteselectedcancelled'] = 'Brisanje izbranih datotek preklicano';
$lang['recursetext'] = 'Poglobitev v podmape';
$lang['nofilesselected'] = 'Nobena datoteka ni izbrana';
$lang['moveselected'] = 'Premakni izbrane datoteke';
$lang['copyselected'] = 'Kopiraj izbrane datoteke';
$lang['selecttargetdir'] = 'Izberite mapo v katero želite kopirati/premakniti';
$lang['movedto'] = 'premaknjeno v';
$lang['copiedto'] = 'kopirano v';
$lang['couldnotmove'] = 'ni bilo mogoče premakniti';
$lang['couldnotcopy'] = 'ni bilo mogoče prekopirati';
$lang['rename'] = 'Preimenuj';
$lang['newname'] = 'Novo ime:';
$lang['renamesuccess'] = 'Datoteka uspe&scaron;no preimanovana';
$lang['renamefailure'] = 'Napaka pri preimenovanju datoteke';
$lang['renamecancelled'] = 'Preimenovanje preklicano';
$lang['owner'] = 'Lastnik';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostali';
$lang['newpermissions'] = 'Nove pravice:';
$lang['setpermissions'] = 'Nastavi pravice';
$lang['permissionstyle'] = 'Stil pravic';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Hiter chmod (npr. 777)';
$lang['chmod'] = 'Spremeni pravice';
$lang['chmodselected'] = 'Spremeni pravice na izbranih datotekah';
$lang['chmodsuccess'] = 'Datoteka je uspe&scaron;no dobila nove pravice';
$lang['chmodfailure'] = 'Spreminjanje pravic datoteke ni bilo uspe&scaron;no';
$lang['chmodcancelled'] = 'Spreminjanje pravic preklicano';
$lang['dirchmodfailmulti'] = 'Pri&scaron;lo je do napake pri spreminjanju pravic mape. Nekatere datoteke v tej mapi so morda kljub temu dobile nove pravice..';
$lang['dirchmodsuccessmulti'] = 'Spreminjanje pravic na mapi in njeni vsebini je bilo uspe&scaron;no';
$lang['dirchmodsuccess'] = 'Mapa je uspe&scaron;no dobila nove pravice';
$lang['dirchmodfailure'] = 'Spreminjanje pravic mape ni bilo uspe&scaron;no';
$lang['dirnotemptyconfirm'] = 'Mapa ni prazna. Ste prepričani, da jo želite izbrisati skupaj z vso vsebino in podmapami?';
$lang['dirtreedeletecancelled'] = 'Brisanje mape preklicano';
$lang['imsure'] = 'Prepričan sem';
$lang['cancel'] = 'Prekliči';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Naloži novo datoteko(e)';
$lang['unpackafterupload'] = 'Naj poizkusim ekstrahirati datoteko po naložitvi (samo tgz in zip datoteke)?';
$lang['uploadsuccess'] = 'je uspe&scaron;no naložena';
$lang['uploadfail'] = 'ni bilo mogoče naložiti';
$lang['unpacksuccess'] = 'je uspe&scaron;no ekstrahirana';
$lang['unpackfail'] = ' neuspe&scaron;no z napako:';
$lang['packfileopenfail'] = 'Ne morem odpreti kompresirane datoteke za ekstrahiranje (nepodprt format?)';
$lang['packfilewritefail'] = 'Ne morem odpreti datoteke &amp;s za pisanje';
$lang['currentpath'] = 'Trenutna pot:';
$lang['newdirname'] = 'Ustvari novo mapo:';
$lang['newdirsuccess'] = 'Mapa je bila uspe&scaron;no ustvarjena';
$lang['newdirfail'] = 'Napaka pri ustvarjanju nove mape';
$lang['filedateformat'] = 'd.m.Y H:m:s';
$lang['iconsize'] = 'Velikost ikone';
$lang['smallicons'] = 'Majhne ikone';
$lang['largeicons'] = 'Velike ikone';
$lang['thousanddelimiter'] = 'Ločitelj tisočic';
$lang['none'] = 'Noben';
$lang['space'] = 'prostor';
$lang['showthumbnails'] = 'Prikaži pomanj&scaron;ave';
$lang['showthumbnailshelp'] = 'Če omogočite to možnost bodo prikazane pomanj&scaron;ave slikovnih datotek, če le-te obstajajo, datoteke pomanj&scaron;av bodo skrite. Če to možnost onemogočite, bodo prikazane vse datoteke.';
$lang['uploadfilesto'] = 'Nalaganje datotek v:';
$lang['uploadview'] = 'Naloži datoteke';
$lang['uploadboxes'] = '&Scaron;tevilo polj za nalaganje';
$lang['nothinguploaded'] = 'Nič ni bilo prene&scaron;eno';
$lang['unsupportedarchive'] = 'Nepodprt format arhiva';
$lang['uploadmethod'] = 'Metoda nalaganja';
$lang['uploaderstandard'] = 'Standardna HTML input metoda (omogoča ekstrahiranje)';
$lang['enableadvanced'] = 'Omogoči napredni način?';
$lang['advancedhelp'] = 'Omogoča dostop do celotnega CMS sistema, ne samo mape /uploads/ (če je to dovoljeno)';
$lang['showhiddenfileshelp'] = 'Učinkovito samo ob aktiviranem naprednem načinu';
$lang['showhiddenfiles'] = 'Prikaži skrite datoteke';
$lang['settingsconfirmsingledelete'] = 'Potrditev brisanja posamezne datoteke?';
$lang['settingssaved'] = 'Nastavitve shranjene';
$lang['help'] = '		<h3>Kaj to počne?</h3>
		<p>Modul omogoča upravljanje z datotekami</p>
		<h3>Kako to uporabim?</h3>
		<p>Izberite iz menija vsebina v administraciji. </p>';
$lang['utma'] = '156861353.946566493304929700.1236179099.1236861512.1239346306.7';
$lang['utmz'] = '156861353.1236861512.6.5.utmccn=(referral)|utmcsr=jupiter.sinusiks.net|utmcct=/admin/addtemplate.php|utmcmd=referral';
$lang['utmb'] = '156861353.2.10.1239346306';
$lang['utmc'] = '156861353';
?>
